@@ -36,7 +36,7 @@ Group by StressVowel,buckeye_speaker.Number""")
 
 def loadFile(path,cols=None):
     with open(path,'r') as f:
-        head = pop(f,0).strip().split("\t")
+        head = f.pop(0).strip().split("\t")
         lines = []
         for l in f:
             line = l.strip().split("\t")
